@@ -19,14 +19,7 @@
 #include <QFileInfo>
 #include <QFile>
 #include <QStringList>
-#include <qplatformdefs.h>
-#ifdef Q_OS_SYMBIAN
-#include <QCoreApplication>
-#elif QT_VERSION >= 0x050000
-#include <QStandardPaths>
-#else
-#include <QDesktopServices>
-#endif
+
 
 Utils::Utils(QObject *parent) :
     QObject(parent)
@@ -62,52 +55,21 @@ QString Utils::fileSizeFromBytes(double bytes) {
     QString size;
 
     if (bytes > gb) {
-        size = QString::number(bytes / gb, 'f', 2) + "GB";
+        size = QString::number(bytes / gb, 'f', 2) + " GB";
     }
     else if (bytes > mb) {
-        size = QString::number(bytes / mb, 'f', 2) + "MB";
+        size = QString::number(bytes / mb, 'f', 2) + " MB";
     }
     else if (bytes > kb){
-        size = QString::number(bytes / kb, 'f', 2) + "KB";
+        size = QString::number(bytes / kb, 'f', 2) + " kB";
     }
     else {
-        size = QString::number(bytes) + "B";
+        size = QString::number(bytes) + " B";
     }
 
     return size;
 }
 
-QString Utils::dateFromSecs(qint64 secs, bool showTime) {
-    return Utils::dateFromMSecs(secs * 1000, showTime);
-}
-
-QString Utils::dateFromMSecs(qint64 msecs, bool showTime) {
-    QString date;
-
-    if (showTime) {
-        date = QDateTime::fromMSecsSinceEpoch(msecs).toString("dd/MM/yyyy | HH:mm");
-    }
-    else {
-        date = QDateTime::fromMSecsSinceEpoch(msecs).toString("dd/MM/yyyy");
-    }
-
-    return date;
-}
-
-QString Utils::base64Id(const QString &artist, const QString &title) {
-    return QString(artist.toAscii().toBase64() + "-" + title.toAscii().toBase64());
-}
-
-QString Utils::localDateTimeFromString(const QString &dateTimeString, Qt::DateFormat format) {
-    QDateTime dt = QDateTime::fromString(dateTimeString, format);
-
-    if (!dt.isValid()) {
-        dt = QDateTime::currentDateTimeUtc();
-    }
-
-    return dt.toLocalTime().toString("dd/MM/yyyy | HH:mm");
-}
-
 QString Utils::httpErrorString(int errorCode) {
     switch (errorCode) {
     case 400:
@@ -138,7 +100,9 @@ QString Utils::httpErrorString(int errorCode) {
 bool Utils::urlIsPlaylist(const QUrl &url) {
     QString urlString = url.toString().toLower();
 
-    return (url.host() == "opml.radiotime.com") || (urlString.endsWith(".pls")) || (urlString.endsWith(".asx")) || (urlString.endsWith(".m3u")) || (urlString.endsWith(".smil"));
+    return ((urlString.endsWith(".pls")) || (urlString.endsWith(".asx")) 
+            || (urlString.endsWith(".m3u")) || (urlString.endsWith(".smil"))
+            || (urlString.endsWith(".ram")));
 }
 
 QString Utils::capitalise(const QString &string) {
@@ -158,6 +122,16 @@ QString Utils::capitalise(const QString &string) {
     return capitalised.trimmed();
 }
 
+QString Utils::buildString(const QString &str, const QStringList &args) {
+    QString bs(str);
+    
+    for (int i = 0; i < args.size(); i++) {
+        bs = bs.arg(args.at(i));
+    }
+    
+    return bs;
+}
+
 void Utils::log(const QString &filePath, const QByteArray &message) {
     QFile lf(filePath);
 
@@ -167,19 +141,3 @@ void Utils::log(const QString &filePath, const QByteArray &message) {
 
     lf.close();
 }
-
-QString Utils::versionNumber() {
-    return QString("0.2.1");
-}
-
-QString Utils::logoPath() {
-#ifdef Q_OS_SYMBIAN
-    return QCoreApplication::applicationDirPath() + "/.logos/";
-#elif (defined MEEGO_EDITION_HARMATTAN) || (defined Q_WS_MAEMO_5)
-    return QString("/home/user/cuteRadio/.logos/");
-#elif QT_VERSION >= 0x050000
-    return QStandardPaths::writeableLocation(QStandardPaths::HomeLocation) + "/cuteRadio/.logos/";
-#else
-    return QDesktopServices::storageLocation(QDesktopServices::HomeLocation) + "/cuteRadio/.logos/";
-#endif
-}
